searchData={"content_type":"text/markdown","items":[{"doc":"Documentation for `Tucan`.","ref":"Tucan.html","title":"Tucan","type":"module"},{"doc":"Returns the specification of an area plot.","ref":"Tucan.html#area/4","title":"Tucan.area/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:interpolate` - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a polyline.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n* `:tension` (`t:float/0`) - Depending on the interpolation type, sets the tension parameter\n* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:points` (`t:boolean/0`) - Whether points will be included in the chart. The default value is `false`.\n* `:line` (`t:boolean/0`) - Whether the line will be included in the chart The default value is `false`.\n* `:mode` - The stacking mode, applied only if `:color_by` is set. Can be one of the\n  following:\n    * `:stacked` - the default one, areas are stacked \n    * `:normalize` - the stacked charts are normalized\n    * `:streamgraph` - the chart is displaced around a central axis\n    * `:no_stack` - no stacking is applied The default value is `:stacked`.\n\n\n\n#","ref":"Tucan.html#area/4-options","title":"Options - Tucan.area/4","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#area/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.area/4","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#area/4-interactivity-options","title":"Interactivity Options - Tucan.area/4","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#area/4-global-options","title":"Global Options - Tucan.area/4","type":"function"},{"doc":"A simple area chart of Google stock price over time. Notice how we change the\n`x` axis type from the default (`:quantitative`) to `:temporal` using the generic\n`:x` channel configuration option: \n\n```tucan\nTucan.area(:stocks, \"date\", \"price\", x: [type: :temporal])\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nYou can overlay the points and/or the line:\n\n```tucan\nTucan.area(:stocks, \"date\", \"price\", x: [type: :temporal], points: true, line: true)\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nIf you add the `:color_by` property then the area charts are stacked by default. Below\nyou can see how the generic encoding options can be used in order to modify any part\nof the underlying `VegaLite` specification:\n\n```tucan\nTucan.area(:unemployment, \"date\", \"count\",\n  color_by: \"series\",\n  x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n  y: [aggregate: :sum],\n  color: [scale: [scheme: \"category20b\"]],\n  width: 300,\n  height: 200,\n  fill_opacity: 1.0\n)\n```\n\nYou could change the mode to `:normalize` or `:stramgraph`:\n\n```tucan\nleft =\n  Tucan.area(:unemployment, \"date\", \"count\",\n    color_by: \"series\",\n    mode: :normalize,\n    x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n    y: [aggregate: :sum]\n  )\n  |> Tucan.set_title(\"normalize\")\n\nright =\n  Tucan.area(:unemployment, \"date\", \"count\",\n    color_by: \"series\",\n    mode: :streamgraph,\n    x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n    y: [aggregate: :sum]\n  )\n  |> Tucan.set_title(\"streamgraph\")\n\nVegaLite.concat(VegaLite.new(), [left, right], :horizontal)\n```\n\nOr you could disable the stacking at all:\n\n```tucan\nTucan.area(:stocks, \"date\", \"price\",\n  color_by: \"symbol\",\n  mode: :no_stack,\n  x: [type: :temporal],\n  width: 400\n)\n|> Tucan.Axes.set_y_scale(:log)\n```","ref":"Tucan.html#area/4-examples","title":"Examples - Tucan.area/4","type":"function"},{"doc":"Returns the specification of a bar chart.\n\nA bar chart is consisted by a categorical `field` and a numerical `value` field that\ndefines the height of the bars. You can create a grouped bar chart by setting\nthe `:color_by` option.\n\nAdditionally you should specify the aggregate for the `y` values, if your dataset contains\nmore than one values per category.","ref":"Tucan.html#bar/4","title":"Tucan.bar/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:orient` - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:mode` - The stacking mode, applied only if `:color_by` is set. Can be one of the\n  following:\n    * `:stacked` - the default one, bars are stacked \n    * `:normalize` - the bars are stacked are normalized\n    * `:grouped` - no stacking is applied, a separate bar for each category The default value is `:stacked`.\n\n\n\n#","ref":"Tucan.html#bar/4-options","title":"Options - Tucan.bar/4","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:x_offset` (`t:keyword/0`) - Extra vega lite options for the `:x_offset` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#bar/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.bar/4","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#bar/4-interactivity-options","title":"Interactivity Options - Tucan.bar/4","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#bar/4-global-options","title":"Global Options - Tucan.bar/4","type":"function"},{"doc":"A simple bar chart:\n\n```tucan\ndata = [\n  %{\"a\" => \"A\", \"b\" => 28}, %{\"a\" => \"B\", \"b\" => 55}, %{\"a\" => \"C\", \"b\" => 43},\n  %{\"a\" => \"D\", \"b\" => 91}, %{\"a\" => \"E\", \"b\" => 81}, %{\"a\" => \"F\", \"b\" => 53},\n  %{\"a\" => \"G\", \"b\" => 19}, %{\"a\" => \"H\", \"b\" => 87}, %{\"a\" => \"I\", \"b\" => 52}\n]\n\nTucan.bar(data, \"a\", \"b\")\n```\n\nYou can set a `color_by` option that will create a stacked bar chart:\n\n```tucan\nTucan.bar(:weather, \"date\", \"date\",\n  color_by: \"weather\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :month],\n  y: [aggregate: :count]\n)\n```\n\nIf you set the mode option to `:grouped` you will instead have a different bar\nper group, you can also change the orientation by setting the `:orient` flag.\nSimilarly you can set the mode to `:normalize` in order to have normalized\nstacked bars.\n\n```tucan\ndata = [\n    %{\"category\" => \"A\", \"group\" => \"x\", \"value\" => 0.1},\n    %{\"category\" => \"A\", \"group\" => \"y\", \"value\" => 0.6},\n    %{\"category\" => \"A\", \"group\" => \"z\", \"value\" => 0.9},\n    %{\"category\" => \"B\", \"group\" => \"x\", \"value\" => 0.7},\n    %{\"category\" => \"B\", \"group\" => \"y\", \"value\" => 0.2},\n    %{\"category\" => \"B\", \"group\" => \"z\", \"value\" => 1.1},\n    %{\"category\" => \"C\", \"group\" => \"x\", \"value\" => 0.6},\n    %{\"category\" => \"C\", \"group\" => \"y\", \"value\" => 0.1},\n    %{\"category\" => \"C\", \"group\" => \"z\", \"value\" => 0.2}\n]\n\ngrouped =\n  Tucan.bar(\n    data, \"category\", \"value\",\n    color_by: \"group\",\n    mode: :grouped,\n    orient: :vertical\n  )\n\nnormalized =\n  Tucan.bar(\n    data, \"category\", \"value\",\n    color_by: \"group\",\n    mode: :normalize\n  )\n\nVegaLite.concat(VegaLite.new(), [grouped, normalized], :horizontal)\n```","ref":"Tucan.html#bar/4-examples","title":"Examples - Tucan.bar/4","type":"function"},{"doc":"Returns the specification of a box plot.\n\nBy default a one dimensional box plot of the `:field` - which must be a numerical variable - is\ngenerated. You can add a second dimension across a categorical variable by either setting the\n`:group` or `:color_by` options.\n\nBy default a Tukey box plot will be generated. In the Tukey box plot the whisker spans from\nthe smallest data to the largest data within the range `[Q1 - k * IQR, Q3 + k * IQR]` where\n`Q1`and `Q3` are the first and third quartiles while `IQR` is the interquartile range\n`(Q3-Q1)`. You can specify if needed the constant `k` which defaults to 1.5.\n\nAdditionally you can set the `mode` to `:min_max`  where the lower and upper whiskers are\ndefined as the min and max respectively. No points will be considered as outliers for this\ntype of box plots. In this case the `k` value is ignored.\n\n> ##","ref":"Tucan.html#boxplot/3","title":"Tucan.boxplot/3","type":"function"},{"doc":">\n> A box plot (box and whisker plot) displays the five-number summary of a set of data. The\n> five-number summary is the minimum, first quartile, median, third quartile, and maximum.\n> In a box plot, we draw a box from the first quartile to the third quartile. A vertical\n> line goes through the box at the median.","ref":"Tucan.html#boxplot/3-what-is-a-box-plot-info","title":"What is a box plot {: .info} - Tucan.boxplot/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:orient` - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:group` (`t:String.t/0`) - A field to be used for grouping the boxplot. It is used for adding a second dimension to\n  the plot. If not set the plot will be one dimensional. Notice that a grouping is automatically\n  applied if the `:color_by` option is set.\n* `:mode` - The type of the box plot. Either a Tukey box plot will be created or a min-max plot. The default value is `:tukey`.\n* `:k` (`t:float/0`) - The constant used for calculating the extent of the whiskers in a Tukey boxplot. Applicable\n  only if `:mode` is set to `:tukey`. The default value is `1.5`.\n\n\n\n#","ref":"Tucan.html#boxplot/3-options","title":"Options - Tucan.boxplot/3","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#boxplot/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.boxplot/3","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#boxplot/3-interactivity-options","title":"Interactivity Options - Tucan.boxplot/3","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#boxplot/3-global-options","title":"Global Options - Tucan.boxplot/3","type":"function"},{"doc":"A one dimensional Tukey boxplot: \n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\")\n```\n\nYou can set `:group` or `:color_by` in order to set a second dimension:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\")\n```\n\nYou can set the mode to `:min_max` in order to extend the whiskers to the min and max values:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\", mode: :min_max)\n```\n\nBy setting the `:orient` to `:vertical` you can change the default horizontal orientation:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\", orient: :vertical)\n```","ref":"Tucan.html#boxplot/3-examples","title":"Examples - Tucan.boxplot/3","type":"function"},{"doc":"Returns the specification of a bubble plot.\n\nA bubble plot is a scatter plot with a third parameter defining the size of the dots.\n\nAll `x`, `y` and `size` must be numerical data fields.\n\nSee also `scatter/4`.","ref":"Tucan.html#bubble/5","title":"Tucan.bubble/5","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n\n\n#","ref":"Tucan.html#bubble/5-options","title":"Options - Tucan.bubble/5","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#bubble/5-encodings-custom-options","title":"Encodings Custom Options - Tucan.bubble/5","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#bubble/5-interactivity-options","title":"Interactivity Options - Tucan.bubble/5","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#bubble/5-global-options","title":"Global Options - Tucan.bubble/5","type":"function"},{"doc":"```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", width: 400)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n```\n\nYou could use a fourth variable to color the graph. As always you can set the `tooltip` in\norder to make the plot interactive:\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", color_by: \"region\", width: 400, tooltip: :data)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n```\n\nIt makes more sense to use a log scale for the _x axis_:\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", color_by: \"region\", width: 400, tooltip: :data)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n|> Tucan.Axes.set_x_scale(:log)\n```","ref":"Tucan.html#bubble/5-examples","title":"Examples - Tucan.bubble/5","type":"function"},{"doc":"Adds a `color` encoding for the given field.\n\n`opts` can be an arbitrary keyword list with vega-lite supported options.\n\nIf `:recursive` is set the encoding is applied in all subplots of the given plot.","ref":"Tucan.html#color_by/3","title":"Tucan.color_by/3","type":"function"},{"doc":"Plot the counts of observations for a categorical variable.\n\nTakes a categorical `field` as input and generates a count plot\nvisualization. By default the counts are plotted on the *y-axis*\nand the categorical `field` across the *x-axis*.\n\nThis is similar to `histogram/3` but specifically for a categorical\nvariable.\n\nThis is a simple wrapper around `bar/4` where by default the count of\nobservations is mapped to the `y` variable.\n\n> ##","ref":"Tucan.html#countplot/3","title":"Tucan.countplot/3","type":"function"},{"doc":"> \n> A countplot is a type of bar chart used in data visualization to\n> display the **frequency of occurrences of categorical data**. It is\n> particularly useful for visualizing the *distribution* and *frequency*\n> of different categories within a dataset.\n>\n> In a countplot, each unique category is represented by a bar, and the\n> height of the bar corresponds to the number of occurrences of that\n> category in the data.","ref":"Tucan.html#countplot/3-what-is-a-countplot-tip","title":"What is a countplot? {: .tip} - Tucan.countplot/3","type":"function"},{"doc":"See `bar/4`","ref":"Tucan.html#countplot/3-options","title":"Options - Tucan.countplot/3","type":"function"},{"doc":"We will use the `:titanic` dataset on the following examples. We can\nplot the number of passengers by ticket class:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\")\n```\n\nYou can make the bars horizontal by setting the `:orient` option:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", orient: :vertical)\n```\n\nYou can set `:color_by` to group it by a second variable:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", color_by: \"Survived\")\n```\n\nBy default the bars are stacked. You can unstack them by setting the\n`:mode` to `:grouped`\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", color_by: \"Survived\", mode: :grouped)\n```","ref":"Tucan.html#countplot/3-examples","title":"Examples - Tucan.countplot/3","type":"function"},{"doc":"Plot the distribution of a numeric variable.\n\nDensity plots allow you to visualize the distribution of a numeric variable for one\nor several groups. If you want to draw the density for several groups you need to\nspecify the `:color_by` option which is assumed to be a categorical variable.\n\n> #","ref":"Tucan.html#density/3","title":"Tucan.density/3","type":"function"},{"doc":">\n> Since the grouping variable must also be used for properly calculating the density\n> transformation you **should avoid calling the `color_by/3` grouping function** after\n> a `density/3` call. Instead use the `:color_by` option, which will ensure that the\n> proper settings are applied to the underlying transformation.\n>\n> Calling `color_by/3` would produce this graph:\n>\n> ```tucan\n> Tucan.density(:penguins, \"Body Mass (g)\")\n> |> Tucan.color_by(\"Species\")\n> ```\n>\n> In the above case the density function has been calculated on the complete dataset\n> and you cannot color by the `Species`. Instead you should use the `:color_by`\n> option which would calculate the density function per group:\n>\n> ```tucan\n> Tucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.2)\n> ```\n>\n> Alternatively you should use the `:groupby` option in order to group the density\n> tranform by the `Species` field and then apply the `color_by/3` function:\n>\n> ```tucan\n> Tucan.density(:penguins, \"Body Mass (g)\", groupby: [\"Species\"])\n> |> Tucan.color_by(\"Species\")\n> ```\n\nSee also `histogram/3`.","ref":"Tucan.html#density/3-avoid-calling-color_by-3-with-a-density-plot-warning","title":"Avoid calling `color_by/3` with a density plot {: .warning} - Tucan.density/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:groupby` (list of `t:String.t/0`) - The data fields to group by. If not specified, a single group containing all data\n  objects will be used. This is applied only on the density transform.\n\n  In most cases you only need to set `color_by` which will automatically handle the\n  density transform grouping. Use `groupby` only if you want to manually post-process\n  the generated specification, or if you want to apply grouping by more than one\n  variable.\n\n  If both `groupby` and `color_by` are set then only `groupby` is used for grouping\n  the density transform and `color_by` is used for encoding the color.\n* `:cumulative` (`t:boolean/0`) - A boolean flag indicating whether to produce density estimates (false) or cumulative\n  density estimates (true). The default value is `false`.\n* `:counts` (`t:boolean/0`) - A boolean flag indicating if the output values should be probability estimates\n  (false) or smoothed counts (true). The default value is `false`.\n* `:bandwidth` (`t:float/0`) - The bandwidth (standard deviation) of the Gaussian kernel. If unspecified or set to\n  zero, the bandwidth value is automatically estimated from the input data using\n  Scott’s rule.\n* `:extent` - A `[min, max]` domain from which to sample the distribution. If unspecified, the extent\n  will be determined by the observed minimum and maximum values of the density value field.\n* `:minsteps` (`t:integer/0`) - The minimum number of samples to take along the extent domain for plotting the density. The default value is `25`.\n* `:maxsteps` (`t:integer/0`) - The maximum number of samples to take along the extent domain for plotting the density. The default value is `200`.\n* `:steps` (`t:integer/0`) - The exact number of samples to take along the extent domain for plotting the density. If\n  specified, overrides both minsteps and maxsteps to set an exact number of uniform samples.\n  Potentially useful in conjunction with a fixed extent to ensure consistent sample points\n  for stacked densities.\n\n\n\n#","ref":"Tucan.html#density/3-options","title":"Options - Tucan.density/3","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#density/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.density/3","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#density/3-interactivity-options","title":"Interactivity Options - Tucan.density/3","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#density/3-global-options","title":"Global Options - Tucan.density/3","type":"function"},{"doc":"```tucan\nTucan.density(:penguins, \"Body Mass (g)\")\n```\n\nIt is a common use case to compare the density of several groups in a dataset. Several\noptions exist to do so. You can plot all items on the same chart, using transparency and\nannotation to make the comparison possible.\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\")\n```\n\nYou can also combine it with `facet_by/4` in order to draw a different plot for each value\nof the grouping variable. Notice that we need to set the `:groupby` variable in order\nto correctly calculate the density plot per field's value.\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", groupby: [\"Species\"])\n|> Tucan.color_by(\"Species\")\n|> Tucan.facet_by(:column, \"Species\")\n```\n\nYou can control the smoothing by setting a specific `bandwidth` value (if not set it is\nautomatically calculated by vega lite):\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", bandwidth: 20.0)\n```\n\nYou can plot a cumulative density distribution by setting the `:cumulative` option to `true`:\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", cumulative: true)\n```\n\nor calculate a separate cumulative distribution for each group: \n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", cumulative: true, color_by: \"Species\")\n|> Tucan.facet_by(:column, \"Species\")\n```","ref":"Tucan.html#density/3-examples","title":"Examples - Tucan.density/3","type":"function"},{"doc":"Draws a density heatmap.\n\nA density heatmap is a bivariate histogram, e.g. the `x`, `y` data are binned\nwithin rectangles that tile the plot and then the count of observations within\neach rectangle is shown with the fill color.\n\nBy default the `count` of observations within each rectangle is encoded, but you\ncan calculate the statistic of any field and use it instead. \n\nDensity heatmaps are a powerful visualization tool that find their best use cases\nin situations where you need to explore and understand the distribution and\nconcentration of data points in a two-dimensional space. They are particularly\neffective when dealing with large datasets, allowing you to uncover patterns,\nclusters, and trends that might be difficult to discern in raw data.","ref":"Tucan.html#density_heatmap/4","title":"Tucan.density_heatmap/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:z` (`t:String.t/0`) - If set corresponds to the field that will be used for calculating the color fo the\n  bin using the provided aggregate. If not set (the default behaviour) the count of\n  observations are used for coloring the bin.\n* `:aggregate` (`t:atom/0`) - The statistic that will be used for aggregating the observations within a bin. The\n  `z` field must be set if `aggregate` is set.\n\n\n\n#","ref":"Tucan.html#density_heatmap/4-options","title":"Options - Tucan.density_heatmap/4","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#density_heatmap/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.density_heatmap/4","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#density_heatmap/4-interactivity-options","title":"Interactivity Options - Tucan.density_heatmap/4","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#density_heatmap/4-global-options","title":"Global Options - Tucan.density_heatmap/4","type":"function"},{"doc":"Let's start with a default denisty heatmap on the penguins dataset:\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\")\n```\n\nYou can summarize over another field:\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\", z: \"Body Mass (g)\", aggregate: :mean)\n```","ref":"Tucan.html#density_heatmap/4-examples","title":"Examples - Tucan.density_heatmap/4","type":"function"},{"doc":"Draw a donut chart.\n\nA donut chart is a circular visualization that resembles a pie chart but\nfeatures a hole at its center. This central hole creates a _donut_ shape,\ndistinguishing it from traditional pie charts. \n\nThis is a wrapper around `pie/4` that sets by default the `:inner_radius`.","ref":"Tucan.html#donut/4","title":"Tucan.donut/4","type":"function"},{"doc":"See `pie/4`","ref":"Tucan.html#donut/4-options","title":"Options - Tucan.donut/4","type":"function"},{"doc":"```tucan\nTucan.donut(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n|> Tucan.facet_by(:column, \"year\", type: :nominal)\n```","ref":"Tucan.html#donut/4-examples","title":"Examples - Tucan.donut/4","type":"function"},{"doc":"Apply facetting on the input plot `vl` by the given `field`.\n\nThis will create multiple plots either horizontally (`:column` faceting mode) or\nvertically (`:row` faceting mode), one for each distinct value of the given\n`field`, which must be a categorical variable.\n\n`opts` is an arbitraty keyword list that will be passed to the `:row` or `:column`\nencoding.\n\n> ##","ref":"Tucan.html#facet_by/4","title":"Tucan.facet_by/4","type":"function"},{"doc":">\n> Facet plots, also known as trellis plots or small multiples, are figures made up\n> of multiple subplots which have the same set of axes, where each subplot shows\n> a subset of the data.","ref":"Tucan.html#facet_by/4-facet-plots-info","title":"Facet plots {: .info} - Tucan.facet_by/4","type":"function"},{"doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.facet_by(:column, \"species\")\n|> Tucan.color_by(\"species\")\n```","ref":"Tucan.html#facet_by/4-examples","title":"Examples - Tucan.facet_by/4","type":"function"},{"doc":"Adds a `fill` encoding for the given field.\n\n`opts` can be an arbitrary keyword list with vega-lite supported options.\n\nIf `:recursive` is set the encoding is applied in all subplots of the given plot.","ref":"Tucan.html#fill_by/3","title":"Tucan.fill_by/3","type":"function"},{"doc":"Flips the axes of the provided chart.\n\nThis works for both one dimensional and two dimensional charts. All positional channels\nthat are defined will be flipped.\n\nThis is used internally by plots that support setting orientation.","ref":"Tucan.html#flip_axes/1","title":"Tucan.flip_axes/1","type":"function"},{"doc":"Plots a histogram.\n\nSee also `density/3`","ref":"Tucan.html#histogram/3","title":"Tucan.histogram/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:relative` (`t:boolean/0`) - If set a relative frequency histogram is generated. The default value is `false`.\n* `:orient` - Histogram's orientation. It specifies the axis along which the field values\n  are plotted. The default value is `:horizontal`.\n* `:color_by` (`t:String.t/0`) - The field to group observations by. This will used for coloring the histogram\n  if set.\n* `:maxbins` (`t:integer/0`) - Maximum number of bins.\n* `:step` - An exact step size to use between bins. If provided, options such as `maxbins`\n  will be ignored.\n* `:extent` - A two-element (`[min, max]`) array indicating the range of desired bin values.\n* `:stacked` (`t:boolean/0`) - If set it will stack the group histograms instead of layering one over another. Valid\n  only if a semantic grouping has been applied.\n\n\n\n#","ref":"Tucan.html#histogram/3-options","title":"Options - Tucan.histogram/3","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:x2` (`t:keyword/0`) - Extra vega lite options for the `:x2` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#histogram/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.histogram/3","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#histogram/3-interactivity-options","title":"Interactivity Options - Tucan.histogram/3","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#histogram/3-global-options","title":"Global Options - Tucan.histogram/3","type":"function"},{"doc":"Histogram of `Horsepower`\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\")\n```\n\nYou can flip the plot by setting the `:orient` option to `:vertical`:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", orient: :vertical)\n```\n\nBy setting the `:relative` flag you can get a relative frequency histogram:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", relative: true)\n```\n\nYou can increase the number of bins by settings the `maxbins` or the `step` options:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", step: 5)\n```\n\nYou can draw multiple histograms by grouping the observations by a second\n*categorical* variable:\n\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5)\n```\n\nBy default the histograms are plotted layered, but you can also stack them:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5, stacked: true)\n```\n\nor you can facet it, in order to make the histograms more clear:\n\n```tucan\nhistograms =\n  Tucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\")\n  |> Tucan.facet_by(:column, \"Origin\")\n\nrelative_histograms =\n  Tucan.histogram(:cars, \"Horsepower\", relative: true, color_by: \"Origin\", fill_opacity: 0.5, tooltip: true)\n  |> Tucan.facet_by(:column, \"Origin\")\n\nVegaLite.concat(VegaLite.new(), [histograms, relative_histograms], :vertical)\n```","ref":"Tucan.html#histogram/3-examples","title":"Examples - Tucan.histogram/3","type":"function"},{"doc":"Draw a line plot between `x` and `y`\n\nBoth `x` and `y` are considered numerical variables.","ref":"Tucan.html#lineplot/4","title":"Tucan.lineplot/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:interpolate` - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a polyline.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n* `:tension` (`t:float/0`) - Depending on the interpolation type, sets the tension parameter\n* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:group_by` (`t:String.t/0`) - A field to group by the lines without affecting the style of it.\n* `:points` (`t:boolean/0`) - Whether points will be included in the chart. The default value is `false`.\n* `:filled` (`t:boolean/0`) - Whether the points will be filled or not. Valid only if `:points` is set. The default value is `true`.\n\n\n\n#","ref":"Tucan.html#lineplot/4-options","title":"Options - Tucan.lineplot/4","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#lineplot/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.lineplot/4","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#lineplot/4-interactivity-options","title":"Interactivity Options - Tucan.lineplot/4","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#lineplot/4-global-options","title":"Global Options - Tucan.lineplot/4","type":"function"},{"doc":"Plotting a simple line chart of Google stock price over time. Notice how we change the\n`x` axis type from the default (`:quantitative`) to `:temporal` using the generic\n`:x` channel configuration option: \n\n```tucan\nTucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal])\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nYou could plot all stocks of the dataset with different colors by setting the `:color_by`\noption. If you do not want to color lines differently, you can pass the `:group_by` option\ninstead of `:color_by`:\n\n```tucan\nleft = Tucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal], color_by: \"symbol\")\nright = Tucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal], group_by: \"symbol\")\n\nVegaLite.concat(VegaLite.new(), [left, right], :horizontal)\n```\n\nYou can also overlay the points by setting the `:points` and `:filled` opts. Notice\nthat below we plot by year and aggregating the `y` values:\n\n```tucan\nfilled_points =\n  Tucan.lineplot(:stocks, \"date\", \"price\",\n    x: [type: :temporal, time_unit: :year],\n    y: [aggregate: :mean],\n    color_by: \"symbol\",\n    points: true,\n    tooltip: true,\n    width: 300\n  )\n\nstroked_points =\n  Tucan.lineplot(:stocks, \"date\", \"price\",\n    x: [type: :temporal, time_unit: :year],\n    y: [aggregate: :mean],\n    color_by: \"symbol\",\n    points: true,\n    filled: false,\n    tooltip: true,\n    width: 300\n  )\n\nVegaLite.concat(VegaLite.new(), [filled_points, stroked_points], :horizontal)\n```\n\nYou can use various interpolation methods. Some examples follow:\n\n```tucan\nplots = \n  for interpolation   Tucan.set_title(interpolation)\n  end\n\nVegaLite.concat(VegaLite.new(columns: 2), plots, :wrappable)\n```","ref":"Tucan.html#lineplot/4-examples","title":"Examples - Tucan.lineplot/4","type":"function"},{"doc":"Creates if needed a `VegaLite` plot and adds data to it.\n\nThe behaviour of this function depends on the type of `plotdata`:\n\n* if a `VegaLite.t()` struct is passed then it is returned unchanged.\n* If it is a binary it is considered a url and the `VegaLite.data_from_url/2` is\n  called on a newly created `VegaLite` struct.\n* if it is an atom then it is considered a `Tucan.Dataset` and it is translated to\n  the dataset's url. If the dataset name is invalid an exception is raised.\n* in any other case it is considered a set of data values and the values are set\n  as data to a newly created `VegaLite` struct.","ref":"Tucan.html#new/2","title":"Tucan.new/2","type":"function"},{"doc":"Plot pairwise relationships in a dataset.\n\nThis function expects an array of fields to be provided. A grid will be created\nwhere each numeric variable in `fields` will be shared acrosss the y-axes across\na single row and the x-axes across a single column.\n\n> ##","ref":"Tucan.html#pairplot/3","title":"Tucan.pairplot/3","type":"function"},{"doc":">\n> Notice that currently `pairplot/3` works only with numerical (`:quantitative`)\n> variables. If you need to create a pair plot containing other variable types\n> you need to manually build the grid using the `VegaLite` concatenation operations.","ref":"Tucan.html#pairplot/3-numerical-field-types-warning","title":"Numerical field types {: .warning} - Tucan.pairplot/3","type":"function"},{"doc":"* `:diagonal` - The plot type to be used for the diagonal subplots. Can be one on\n  `:scatter`, `:density` and `:histogram`. The default value is `:scatter`.\n* `:plot_fn` (function of arity 3) - An optional function for customizing the look any subplot. It expects a\n  function with the following signature:\n\n  ```elixir\n  (vl :: VegaLite.t(), row :: {binary(), integer()}, column :: {binary(), integer()})\n    :: VegaLite.t() \n  ```\n\n  where both `row` and `column` are tuples containing the index and field of\n  the current and row and column respectively.\n\n  You are free to specify any function for every cell of the grid.\n\n\n\n#","ref":"Tucan.html#pairplot/3-options","title":"Options - Tucan.pairplot/3","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n\n\n\nNotice that if set `width` and `height` will be applied to individual sub plots. On\nthe other hand `title` is applied to the composite plot.","ref":"Tucan.html#pairplot/3-global-options","title":"Global Options - Tucan.pairplot/3","type":"function"},{"doc":"By default a scatter plot will be drawn for all pairwise plots:\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130)\n```\n\nYou can color the points by another field in to add some semantic mapping. Notice\nthat you need the `recursive` option to `true` for the grouping to be applied on all\ninternal subplots.\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130)\n|> Tucan.color_by(\"species\", recursive: true)\n```\n\nBy specifying the `:diagonal` option you can change the default plot for the diagonal\nelements to a histogram:\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130, diagonal: :histogram)\n|> Tucan.color_by(\"species\", recursive: true)\n```\n\nAdditionally you have the option to configure a `plot_fn` with which we can go crazy and\nmodify any part of the grid based on our needs. `plot_fn` should accept as input a `VegaLite`\nstruct and two tuples containing the row and column fields and indexes. In the following\nexample we draw differently the diagonal, the lower and the upper grid. Notice that we don't\ncall `color_by/3` since we color differently the plots based on their index positions.\n\n```tucan\nTucan.pairplot(:iris, [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"],\n  width: 150,\n  height: 150,\n  plot_fn: fn vl, {row_field, row_index}, {col_field, col_index} ->\n    cond do\n      # For the first two diagonal elements we plot a histogram, no \n      row_index == col_index and row_index  \n        Tucan.histogram(vl, row_field)\n\n      row_index == 2 and col_index == 2 ->\n        Tucan.stripplot(vl, row_field, group: \"species\", style: :tick)\n        |> Tucan.color_by(\"species\") \n        |> Tucan.Axes.put_axis_options(:y, labels: false)  \n\n      # For the other diagonal plots we plot a histogram colored_by the species\n      row_index == col_index ->\n        Tucan.histogram(vl, row_field, color_by: \"species\")\n\n      # For the upper part of the diagram we apply a scatter plot\n      row_index  \n        Tucan.scatter(vl, col_field, row_field)\n        |> Tucan.color_by(\"species\")\n\n      # for anything else scatter plot with a quantitative color scale\n      # and size\n      true ->\n        Tucan.scatter(vl, col_field, row_field)\n        |> Tucan.size_by(\"petal_width\", type: :quantitative)\n        \n    end\n  end\n)\n```","ref":"Tucan.html#pairplot/3-examples","title":"Examples - Tucan.pairplot/3","type":"function"},{"doc":"Draws a pie chart.\n\nA pie chart is a circle divided into sectors that each represents a proportion\nof the whole. The `field` specifies the data column that contains the proportions\nof each category. The chart will be colored by the `caregory` field.\n\n> ##","ref":"Tucan.html#pie/4","title":"Tucan.pie/4","type":"function"},{"doc":">\n> Despite it's popularity pie charts should rarely be used. Pie charts are best\n> suited for displaying a small number of categories and can make it challenging\n> to accurately compare data. They rely on angle perception, which can lead to\n> misinterpretation, and lack the precision offered by other charts like bar\n> charts or line charts.\n>\n> Instead, opt for alternatives such as bar charts for straightforward comparisons,\n> stacked area charts for cumulative effects.\n> \n> The following example showcases the limitations of a pie chart, compared to a\n> bar chart:\n>\n> ```tucan\n> alias VegaLite, as: Vl\n>\n> data = [\n>   %{value: 30, category: \"A\"},\n>   %{value: 33, category: \"B\"},\n>   %{value: 38, category: \"C\"}\n> ]\n> \n> pie = Tucan.pie(Vl.new(), \"value\", \"category\")\n> \n> # TODO: replace with the bar call once implemented\n> bar =\n>   Vl.new()\n>   |> Tucan.new()\n>   |> Vl.mark(:bar)\n>   |> Vl.encode_field(:y, \"category\")\n>   |> Vl.encode_field(:x, \"value\", type: :quantitative)\n>\n> Vl.new()\n> |> Vl.data_from_values(data)\n> |> Vl.concat([pie, bar], :horizontal)\n> |> Tucan.set_title(\"Pie vs Bar chart\", anchor: :middle, offset: 15)\n> ```","ref":"Tucan.html#pie/4-avoid-using-pie-charts-warning","title":"Avoid using pie charts {: .warning} - Tucan.pie/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:inner_radius` (`t:integer/0`) - The inner radius in pixels. `0` for a pie chart, `> 0` for a donut chart. If not\n  set it defaults to 0\n* `:aggregate` (`t:atom/0`) - The statistic to use (if any) for aggregating values per pie slice (e.g. `:mean`).\n\n\n\n#","ref":"Tucan.html#pie/4-options","title":"Options - Tucan.pie/4","type":"function"},{"doc":"* `:theta` (`t:keyword/0`) - Extra vega lite options for the `:thetar` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#pie/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.pie/4","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#pie/4-interactivity-options","title":"Interactivity Options - Tucan.pie/4","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#pie/4-global-options","title":"Global Options - Tucan.pie/4","type":"function"},{"doc":"```tucan\nTucan.pie(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n|> Tucan.facet_by(:column, \"year\", type: :nominal)\n```","ref":"Tucan.html#pie/4-examples","title":"Examples - Tucan.pie/4","type":"function"},{"doc":"Returns the specification of a scatter plot with possibility of several semantic\ngroupings.\n\nBoth `x` and `y` must be `:quantitative`.\n\n> ##","ref":"Tucan.html#scatter/4","title":"Tucan.scatter/4","type":"function"},{"doc":">   \n> The relationship between `x` and `y` can be shown for different subsets of the\n> data using the `color_by`, `size_by` and `shape_by` parameters. This is equivalent\n> to calling the corresponding functions after a `scatter/4` call.\n> \n> These parameters control what visual semantics are used to identify the different\n> subsets. It is possible to show up to three dimensions independently by using all\n> three semantic types, but this style of plot can be hard to interpret and is often\n> ineffective.\n>\n> ```tucan\n> Tucan.scatter(:tips, \"total_bill\", \"tip\",\n>   color_by: \"day\",\n>   shape_by: \"sex\",\n>   size_by: \"size\"\n> )\n> ```\n> \n> The above is equivalent to calling:\n>\n> ```elixir\n> Tucan.scatter(:tips, \"total_bill\", \"tip\")\n> |> Tucan.color_by(\"day\", type: :nominal)\n> |> Tucan.shape_by(\"sex\", type: :nominal)\n> |> Tucan.size_by(\"size\", type: :quantitative)\n> ```\n> \n> Using redundant semantics (i.e. both color and shape for the same variable) can be\n> helpful for making graphics more accessible.\n>\n> ```tucan\n> Tucan.scatter(:tips, \"total_bill\", \"tip\",\n>   color_by: \"day\",\n>   shape_by: \"day\"\n> )\n> ```","ref":"Tucan.html#scatter/4-semantic-groupings-tip","title":"Semantic groupings {: .tip} - Tucan.scatter/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:shape_by` (`t:String.t/0`) - If set a data field that will be used for setting the shape of the data points.\n  It is considered `:nominal` by default.\n* `:size_by` (`t:String.t/0`) - If set a data field that will be used for controlling the size of the data points.\n  It is considered `:quantitative` by default.\n\n\n\n#","ref":"Tucan.html#scatter/4-options","title":"Options - Tucan.scatter/4","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:shape` (`t:keyword/0`) - Extra vega lite options for the `:shape` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#scatter/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.scatter/4","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#scatter/4-interactivity-options","title":"Interactivity Options - Tucan.scatter/4","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph","ref":"Tucan.html#scatter/4-global-options","title":"Global Options - Tucan.scatter/4","type":"function"},{"doc":"> We will use the `:tips` dataset thoughout the following examples.\n\nDrawing a scatter plot betwen two variables:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\")\n```\n\nYou can combine it with `color_by/3` to color code the points:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\")\n|> Tucan.color_by(\"time\")\n```\n\nAssigning the same variable to `shape_by/3` will also vary the markers and create a\nmore accessible plot:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"time\")\n|> Tucan.shape_by(\"time\")\n```\n\nAssigning `color_by/3` and `shape_by/3` to different variables will vary colors and\nmarkers independently:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"time\")\n```\n\nYou can also color the points by a numeric variable, the semantic mapping will be\nquantitative and will use a different default palette:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"size\", type: :quantitative)\n```\n\nA numeric variable can also be assigned to size to apply a semantic mapping to the\nareas of the points:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400, tooltip: :data)\n|> Tucan.color_by(\"size\", type: :quantitative)\n|> Tucan.size_by(\"size\", type: :quantitative)\n```\n\nYou can also combine it with `facet_by/3` in order to group within additional\ncategorical variables, and plot them across multiple subplots.\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 300)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"day\")\n|> Tucan.facet_by(:column, \"time\")\n```\n\nYou can also apply faceting on more than one variables, both horizontally and\nvertically:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 300)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"day\")\n|> Tucan.size_by(\"size\")\n|> Tucan.facet_by(:column, \"time\")\n|> Tucan.facet_by(:row, \"sex\")\n```","ref":"Tucan.html#scatter/4-examples","title":"Examples - Tucan.scatter/4","type":"function"},{"doc":"Sets the width of the plot (in pixels).","ref":"Tucan.html#set_height/2","title":"Tucan.set_height/2","type":"function"},{"doc":"Sets the plot's theme.\n\nCheck `Tucan.Themes` for more details on theming.","ref":"Tucan.html#set_theme/2","title":"Tucan.set_theme/2","type":"function"},{"doc":"Sets the title of the plot.\n\nYou can optionally pass any title option supported by vega-lite to customize the\nstyle of it.","ref":"Tucan.html#set_title/3","title":"Tucan.set_title/3","type":"function"},{"doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.set_title(\"My awesome plot\",\n    color: \"red\",\n    subtitle: \"with a subtitle\",\n    subtitle_color: \"green\",\n    anchor: \"start\"\n  )\n```","ref":"Tucan.html#set_title/3-examples","title":"Examples - Tucan.set_title/3","type":"function"},{"doc":"Sets the width of the plot (in pixels).","ref":"Tucan.html#set_width/2","title":"Tucan.set_width/2","type":"function"},{"doc":"Adds a `shape` encoding for the given field.\n\n`opts` can be an arbitrary keyword list with vega-lite supported options.\n\nIf `:recursive` is set the encoding is applied in all subplots of the given plot.","ref":"Tucan.html#shape_by/3","title":"Tucan.shape_by/3","type":"function"},{"doc":"Adds a `size` encoding for the given field.\n\n`opts` can be an arbitrary keyword list with vega-lite supported options.\n\nIf `:recursive` is set the encoding is applied in all subplots of the given plot.","ref":"Tucan.html#size_by/3","title":"Tucan.size_by/3","type":"function"},{"doc":"Returns the specification of a step chart.\n\nThis is a simple wrapper around `lineplot/4` with `:interpolate` set by default\nto `\"step\"`. If `:interpolate` is set to any of `step, step-before, step-after` it\nwill be used. In any other case defaults to `step`.","ref":"Tucan.html#step/4","title":"Tucan.step/4","type":"function"},{"doc":"Check `lineplot/4`","ref":"Tucan.html#step/4-options","title":"Options - Tucan.step/4","type":"function"},{"doc":"```tucan\nTucan.step(:stocks, \"date\", \"price\", color_by: \"symbol\", width: 300, x: [type: :temporal])\n|> Tucan.Axes.set_y_scale(:log)\n```","ref":"Tucan.html#step/4-examples","title":"Examples - Tucan.step/4","type":"function"},{"doc":"Returns the specification of a streamgraph.\n\nThis is a simple wrapper around `area/4` with `:mode` set by default\nto `:streamgraph`. Any value set to the `:mode` option will be ignored.\n\nA grouping field must also be provided which will be set as `:color_by` to\nthe area chart.","ref":"Tucan.html#streamgraph/5","title":"Tucan.streamgraph/5","type":"function"},{"doc":"Check `area/4`","ref":"Tucan.html#streamgraph/5-options","title":"Options - Tucan.streamgraph/5","type":"function"},{"doc":"```tucan\nTucan.streamgraph(:stocks, \"date\", \"price\", \"symbol\",\n  width: 300,\n  x: [type: :temporal],\n  tooltip: true\n)\n```","ref":"Tucan.html#streamgraph/5-examples","title":"Examples - Tucan.streamgraph/5","type":"function"},{"doc":"Draws a strip plot (categorical scatterplot).\n\nA strip plot is a single-axis scatter plot used to visualize the distribution of\na numerical field. The values are plotted as dots or ticks along one axis, so\nthe dots with the same value may overlap.\n\nYou can use the `:jitter` mode for a better view of overlapping points. In this\ncase points are randomnly shifted along with other axis, which has no meaning in\nitself data-wise.\n\nTypically several strip plots are placed side by side to compare the distribution\nof a numerical value among several categories.","ref":"Tucan.html#stripplot/3","title":"Tucan.stripplot/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:float/0`) - The fill opacity of the plotted elemets. The default value is `0.5`.\n* `:orient` - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:group` (`t:String.t/0`) - A field to be used for grouping the strip plot. If not set the plot will\n  be one dimensional.\n* `:style` - The style of the plot. Can be one of the following:\n    * `:tick` - use ticks for each data point\n    * `:point` - use points for each data point\n    * `:jitter` - use points but also apply some jittering across the other\n    axis\n\n  Use `:jitter` in case of many data points in order to avoid overlaps.\n\n  The default value is `:tick`.\n\n\n\n#","ref":"Tucan.html#stripplot/3-options","title":"Options - Tucan.stripplot/3","type":"function"},{"doc":"* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n* `:y_offset` (`t:keyword/0`) - Extra vega lite options for the `:y_offset` encoding. It can be an arbitrary keyword list.\n  Notice that if set they will be merged with any option set by the plot. Since they\n  have a higher precedence they may override the default settings and affect the\n  generated plot. **The contents are not validated.** The default value is `[]`.\n\n\n\n#","ref":"Tucan.html#stripplot/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.stripplot/3","type":"function"},{"doc":"* `:tooltip` - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n\n\n#","ref":"Tucan.html#stripplot/3-interactivity-options","title":"Interactivity Options - Tucan.stripplot/3","type":"function"},{"doc":"* `:width` (`t:integer/0`) - Width of the image\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n\n\n\n> #","ref":"Tucan.html#stripplot/3-global-options","title":"Global Options - Tucan.stripplot/3","type":"function"},{"doc":"> \n> If style is set to `:tick` the following `VegaLite` represenation is generated:\n>\n> ```elixir\n> Vl.new()\n> |> Vl.mark(:tick)\n> |> Vl.encode_field(:x, field, type: :quantitative)\n> |> Vl.encode_field(:y, opts[:group], type: :nominal)\n> ```\n>\n> If style is set to `:jitter` then a transform is added to generate Gaussian jitter\n> using the Box-Muller transform, and the `y_offset` is also encoded based on this:\n>\n> ```elixir\n> Vl.new()\n> |> Vl.mark(:point)\n> |> Vl.transform(calculate: \"sqrt(-2*log(random()))*cos(2*PI*random())\", as: \"jitter\")\n> |> Vl.encode_field(:x, field, type: :quantitative)\n> |> Vl.encode_field(:y, opts[:group], type: :nominal)\n> |> Vl.encode_field(:y_offset, \"jitter\", type: :quantitative)\n> ```","ref":"Tucan.html#stripplot/3-internal-vegalite-representation-info","title":"Internal `VegaLite` representation {: .info} - Tucan.stripplot/3","type":"function"},{"doc":"Assigning a single numeric variable shows the univariate distribution. The default\nstyle is the `:tick`:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\")\n```\n\nFor very dense distribution it makes more sense to use the `:jitter` style in order\nto reduce overlapping points:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", style: :jitter, height: 30, width: 300)\n```\n\nYou can set the `:group` option in order to add a second dimension. Notice that\nthe field must be categorical.\n\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n```\n\nThe plot would be more clear if you also colored the points with the same field:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n|> Tucan.color_by(\"day\")\n```\n\nOr you can color by a distinct variable to show a multi-dimensional relationship:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n|> Tucan.color_by(\"sex\")\n```\n\nor you can color by a numerical variable:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n|> Tucan.color_by(\"size\", type: :ordinal)\n```\n\nYou could draw the same with points but without jittering:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :point)\n|> Tucan.color_by(\"sex\")\n```\n\nor with ticks which is the default one:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :tick)\n|> Tucan.color_by(\"sex\")\n```\n\nYou can set the `:orient` flag to `:vertical` to change the orientation:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter, orient: :vertical)\n|> Tucan.color_by(\"sex\")\n```","ref":"Tucan.html#stripplot/3-examples","title":"Examples - Tucan.stripplot/3","type":"function"},{"doc":"Adds a `stroke_dash` encoding for the given field.\n\n`opts` can be an arbitrary keyword list with vega-lite supported options.\n\nIf `:recursive` is set the encoding is applied in all subplots of the given plot.","ref":"Tucan.html#stroke_dash_by/3","title":"Tucan.stroke_dash_by/3","type":"function"},{"doc":"","ref":"Tucan.html#t:field/0","title":"Tucan.field/0","type":"type"},{"doc":"","ref":"Tucan.html#t:plotdata/0","title":"Tucan.plotdata/0","type":"type"},{"doc":"Utilities for configuring plot axes.","ref":"Tucan.Axes.html","title":"Tucan.Axes","type":"module"},{"doc":"Sets an arbitrary set of options to the given `encoding` axis object.\n\nNotice that no validation is performed, any option set will be merged with\nthe existing `axis` options of the given `encoding`.\n\nAn `ArgumentError` is raised if the `x` encoding channel is not defined.","ref":"Tucan.Axes.html#put_axis_options/3","title":"Tucan.Axes.put_axis_options/3","type":"function"},{"doc":"Set the title of the given `axis`.","ref":"Tucan.Axes.html#set_title/3","title":"Tucan.Axes.set_title/3","type":"function"},{"doc":"Sets the x axis scale.","ref":"Tucan.Axes.html#set_x_scale/2","title":"Tucan.Axes.set_x_scale/2","type":"function"},{"doc":"Sets the x axis title.","ref":"Tucan.Axes.html#set_x_title/2","title":"Tucan.Axes.set_x_title/2","type":"function"},{"doc":"Sets the x axis scale.","ref":"Tucan.Axes.html#set_y_scale/2","title":"Tucan.Axes.set_y_scale/2","type":"function"},{"doc":"Sets the y axis title.","ref":"Tucan.Axes.html#set_y_title/2","title":"Tucan.Axes.set_y_title/2","type":"function"},{"doc":"","ref":"Tucan.Axes.html#t:axis/0","title":"Tucan.Axes.axis/0","type":"type"},{"doc":"","ref":"Tucan.Axes.html#t:scale/0","title":"Tucan.Axes.scale/0","type":"type"},{"doc":"Common datasets for `Tucan` demos and docs.","ref":"Tucan.Datasets.html","title":"Tucan.Datasets","type":"module"},{"doc":"","ref":"Tucan.Datasets.html#dataset/1","title":"Tucan.Datasets.dataset/1","type":"function"},{"doc":"","ref":"Tucan.Datasets.html#t:t/0","title":"Tucan.Datasets.t/0","type":"type"},{"doc":"Helper utilities for customising a plot's grid.","ref":"Tucan.Grid.html","title":"Tucan.Grid","type":"module"},{"doc":"Set a specific color to the grid for the given channel.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_color/3","title":"Tucan.Grid.set_color/3","type":"function"},{"doc":"A scatter plot with the `y-axis` grid colored red and `x-axis` grid with a custom RGB color:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_color(:y, \"red\")\n|> Tucan.Grid.set_color(:x, \"#2A32F4\")\n```","ref":"Tucan.Grid.html#set_color/3-examples","title":"Examples - Tucan.Grid.set_color/3","type":"function"},{"doc":"Sets the dash style of the grid.\n\n`stroke` and `space` are alternatinv lengths for the dashed grid lines in pixels.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_dash_style/4","title":"Tucan.Grid.set_dash_style/4","type":"function"},{"doc":"A scatter plot with the different dashed styles across the two axes:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_dash_style(:x, 10, 2)\n|> Tucan.Grid.set_dash_style(:y, 2, 10)\n```","ref":"Tucan.Grid.html#set_dash_style/4-examples","title":"Examples - Tucan.Grid.set_dash_style/4","type":"function"},{"doc":"Enables or disables the grid for the plot.\n\nNotice that the grid is enabled by default.\n\nSee also `set_enabled/3` for enabling/disabling specific axis' grid.","ref":"Tucan.Grid.html#set_enabled/2","title":"Tucan.Grid.set_enabled/2","type":"function"},{"doc":"A scatter plot with the grid disabled:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_enabled(false)\n```","ref":"Tucan.Grid.html#set_enabled/2-examples","title":"Examples - Tucan.Grid.set_enabled/2","type":"function"},{"doc":"Enable or disable the grid of a specific `channel`\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_enabled/3","title":"Tucan.Grid.set_enabled/3","type":"function"},{"doc":"A scatter plot with the `y-axis` grid disabled:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_enabled(:y, false)\n```","ref":"Tucan.Grid.html#set_enabled/3-examples","title":"Examples - Tucan.Grid.set_enabled/3","type":"function"},{"doc":"Sets the opacity of the grid lines.\n\nIf not set it defaults to 1.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_opacity/3","title":"Tucan.Grid.set_opacity/3","type":"function"},{"doc":"A scatter plot with the `y-axis` grid colored red and `x-axis` grid with a custom RGB color and\nopacity values set. Also the width is increased to make the opacity changes more clear.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_color(:x, \"red\")\n|> Tucan.Grid.set_color(:y, \"cyan\")\n|> Tucan.Grid.set_opacity(:x, 0.1)\n|> Tucan.Grid.set_opacity(:y, 0.8)\n|> Tucan.Grid.set_width(:x, 3)\n|> Tucan.Grid.set_width(:y, 3)\n```","ref":"Tucan.Grid.html#set_opacity/3-examples","title":"Examples - Tucan.Grid.set_opacity/3","type":"function"},{"doc":"Sets the width of the grid lines.\n\nIf not set it defaults to 1.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_width/3","title":"Tucan.Grid.set_width/3","type":"function"},{"doc":"Helper functions for `Tucan` theme.\n\nA `Tucan` theme is nothing more than a keyword list with a `VegaLite` configuration\nobject with some styles applied and some metadata. Every theme must have the\nfollowing format:\n\n    [\n       theme: [],          # the actual theme configuration\n       name: :name,        # an atom with a unique name\n       doc: \"description\", # a description of the theme,\n       source: \"url\"       # a url to the source of the theme if any for attribution \n    ]","ref":"Tucan.Themes.html","title":"Tucan.Themes","type":"module"},{"doc":"`Tucan` comes pre-packed with a set of themes, borrowed by the [Vega Themes](https://github.com/vega/vega-themes)\nproject. You can set a theme to a plot by calling the `Tucan.set_theme/2` function. If no\ntheme set the default vega-lite theme is used. In all examples below the following example\nplot is used:\n\n```tucan\nscatter =\n  Tucan.scatter(:iris, \"petal_width\", \"petal_length\", tooltip: true)\n  |> Tucan.color_by(\"species\")\n  |> Tucan.shape_by(\"species\")\n\nlines = Tucan.lineplot(:stocks, \"date\", \"price\", color_by: \"symbol\", x: [type: :temporal])\n\narea =\n  Tucan.area(:stocks, \"date\", \"price\", color_by: \"symbol\", mode: :normalize, x: [type: :temporal])\n\ndensity = Tucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.2)\n\nstrip =\n  Tucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n  |> Tucan.color_by(\"sex\")\n\nboxplot = Tucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\")\nhistogram = Tucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5)\n\npie = Tucan.pie(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n\ndonut = Tucan.donut(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n\nheatmap =\n  Tucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\", fill_opacity: 1.0)\n\nfirst_row = VegaLite.concat(VegaLite.new(), [scatter, lines, area], :horizontal)\n\nsecond_row =\n  VegaLite.concat(\n    VegaLite.new(),\n    [density, VegaLite.concat(VegaLite.new(), [strip, boxplot], :vertical), histogram],\n    :horizontal\n  )\n\nthird_row = VegaLite.concat(VegaLite.new(), [pie, donut, heatmap], :horizontal)\n\nVegaLite.concat(VegaLite.new(), [first_row, second_row, third_row], :vertical)\n|> VegaLite.config(legend: [disable: true])\n|> VegaLite.resolve(:scale, color: :independent)\n\n```\n\nThe following themes are currently supported:\n\n* [ggplot2](https://github.com/vega/vega-themes/blob/main/src/theme-ggplot2.ts) - Chart theme modeled after `ggplot2`\n\n\n\n\n* [latimes](https://github.com/vega/vega-themes/blob/main/src/theme-latimes.ts) - Chart theme modeled after the Los Angeles Times","ref":"Tucan.Themes.html#module-default-themes","title":"Default themes - Tucan.Themes","type":"module"},{"doc":"Returns the configuration object for the given theme.\n\nAn exception will be raised if the theme name is invlaid.","ref":"Tucan.Themes.html#theme/1","title":"Tucan.Themes.theme/1","type":"function"},{"doc":"Helper low level utilities for interacting with a `VegaLite` struct","ref":"Tucan.VegaLiteUtils.html","title":"Tucan.VegaLiteUtils","type":"module"},{"doc":"Drops the given encoding channel or channels.\n\nAn error is raised if `vl` is not a single view.","ref":"Tucan.VegaLiteUtils.html#drop_encoding_channels/2","title":"Tucan.VegaLiteUtils.drop_encoding_channels/2","type":"function"},{"doc":"Similar to `VegaLite.encode_field/4` but handles also plain maps.\n\nAccepts as input either a `VegaLite` struct or a plain map that is assumed to be\na `VegaLite` spec, and encodes the given field.\n\nIf the input is a `VegaLite` struct then a `VegaLite` is returned, otherwise a\nmap is returned.\n\nThis is useful in case you want to modify an existing multi-layer/multi-plot spec\nwhere you cannot call directly `VegaLite.encode_field/4`\n\nAll provided options are converted to channel properties.","ref":"Tucan.VegaLiteUtils.html#encode_field_raw/4","title":"Tucan.VegaLiteUtils.encode_field_raw/4","type":"function"},{"doc":"Similar to `VegaLite.encode/3` but handles also plain maps.\n\nAccepts as input either a `VegaLite` struct or a plain map that is assumed to be\na `VegaLite` spec, and encodes the given field.\n\nIf the input is a `VegaLite` struct then a `VegaLite` is returned, otherwise a\nmap is returned.\n\nThis is useful in case you want to modify an existing multi-layer/multi-plot spec\nwhere you cannot call directly `VegaLite.encode/3`\n\nAll provided options are converted to channel properties.","ref":"Tucan.VegaLiteUtils.html#encode_raw/3","title":"Tucan.VegaLiteUtils.encode_raw/3","type":"function"},{"doc":"Gets the configured encoding options for the given `channel` or `nil` if not set.\n\nRaises in case of a non single view.","ref":"Tucan.VegaLiteUtils.html#encoding_options/2","title":"Tucan.VegaLiteUtils.encoding_options/2","type":"function"},{"doc":"iex> VegaLite.new()\n    ...> |> VegaLite.encode_field(:x, \"x\", foo: \"bar\")\n    ...> |> Tucan.VegaLiteUtils.encoding_options(:x)\n    %{\"field\" => \"x\", \"foo\" => \"bar\"}","ref":"Tucan.VegaLiteUtils.html#encoding_options/2-examples","title":"Examples - Tucan.VegaLiteUtils.encoding_options/2","type":"function"},{"doc":"Returns true if the given single view plot has the provided `channel` encoded, `false`\notherwise.\n\nRaises in case of a non single view.","ref":"Tucan.VegaLiteUtils.html#has_encoding?/2","title":"Tucan.VegaLiteUtils.has_encoding?/2","type":"function"},{"doc":"iex> Tucan.VegaLiteUtils.has_encoding?(VegaLite.new(), :x)\n    false\n\n    iex> Tucan.VegaLiteUtils.has_encoding?(VegaLite.encode_field(VegaLite.new(), :x, \"x\"), :x)\n    true","ref":"Tucan.VegaLiteUtils.html#has_encoding?/2-examples","title":"Examples - Tucan.VegaLiteUtils.has_encoding?/2","type":"function"},{"doc":"Puts and merges the given `opts` into the `encoding` options.\n\nThe input can either by a `VegaLite` struct or the spec map. The options will be\ndeep merged with the existing ones.\n\nThe input vega lite representation must be a single view.\n\nIt will raise an `ArgumentError` if:\n\n* The input `vl` is not a single view.\n* The encoding does not exist in the specification an `ArgumentError` will be raised.","ref":"Tucan.VegaLiteUtils.html#put_encoding_options/3","title":"Tucan.VegaLiteUtils.put_encoding_options/3","type":"function"},{"doc":"Puts the given `opts` under the given `key` in the provided `VegaLite` struct.\n\nThis is a destructive operation, any existing value for the provided `key` will be\nreplaced by `opts`.","ref":"Tucan.VegaLiteUtils.html#put_in_spec/3","title":"Tucan.VegaLiteUtils.put_in_spec/3","type":"function"}]}